@@ -5,7 +5,7 @@ use warnings;
 package MooX::Press;
 
 our $AUTHORITY = 'cpan:TOBYINK';
-our $VERSION   = '0.010';
+our $VERSION   = '0.011';
 
 use Types::Standard -is;
 use Exporter::Tiny qw(mkopt);
@@ -77,17 +77,24 @@ sub import {
 	
 	if ($opts{type_library}) {
 		$builder->prepare_type_library($opts{type_library}, %opts);
-	}
 	
-	for my $role (@roles) {
-		my ($pkg_name, $pkg_opts) = @$role;
-		$builder->munge_role_options($pkg_opts, \%opts);
-		$builder->make_type_for_role($pkg_name, $pkg_opts->$_handle_list, %opts);
-	}
-	for my $class (@classes) {
-		my ($pkg_name, $pkg_opts) = @$class;
-		$builder->munge_class_options($pkg_opts, \%opts);
-		$builder->make_type_for_class($pkg_name, $pkg_opts->$_handle_list, %opts);
+		for my $role (@roles) {
+			my ($pkg_name, $pkg_opts) = @$role;
+			$builder->munge_role_options($pkg_opts, \%opts);
+			$builder->make_type_for_role($pkg_name, $pkg_opts->$_handle_list, %opts);
+		}
+		for my $class (@classes) {
+			my ($pkg_name, $pkg_opts) = @$class;
+			$builder->munge_class_options($pkg_opts, \%opts);
+			$builder->make_type_for_class($pkg_name, $pkg_opts->$_handle_list, %opts);
+		}
+	
+		require Type::Registry;
+		my $reg = 'Type::Registry'->for_class($opts{type_library});
+		$reg->add_types($_) for (
+			$opts{type_library},
+			qw( Types::Standard Types::Common::Numeric Types::Common::String Types::TypeTiny ),
+		);
 	}
 	
 	for my $role (@roles) {
@@ -477,7 +484,6 @@ sub _make_package {
 						: undef;
 				};
 				$spec{isa} ||= do {
-					require Types::Standard;
 					Types::Standard::ConsumerOf()->of($target);
 				};
 			}
@@ -489,14 +495,19 @@ sub _make_package {
 						: undef;
 				};
 				$spec{isa} ||= do {
-					require Types::Standard;
 					Types::Standard::InstanceOf()->of($target);
 				};
 			}
 			if ($spec{enum}) {
-				require Types::Standard;
 				$spec{isa} = Types::Standard::Enum()->of(@{delete $spec{enum}});
 			}
+			if (is_Object($spec{type}) and $spec{type}->can('check')) {
+				$spec{isa} = delete $spec{type};
+			}
+			elsif ($spec{type}) {
+				my $reg = 'Type::Registry'->for_class($opts{type_library});
+				$spec{isa} = $reg->lookup(delete $spec{type});
+			}
 			
 			if (ref $spec{isa} && !exists $spec{coerce} && $spec{isa}->has_coercion) {
 				$spec{coerce} = 1;
@@ -1456,6 +1467,14 @@ an object blessed into the "YourApp::HashRef" class.
 
 Use blessed type constraint objects, such as those from L<Types::Standard>.
 
+=item C<< type >> I<< (Str) >>
+
+C<< type => "HashRef" >> does what you think  C<< isa => "HashRef" >> should
+do. More specifically it searches your type library, along with
+L<Types::Standard>, L<Types::Common::Numeric>, and L<Types::Common::String>
+to find the type constraint it thinks you wanted. It's smart enough to deal
+with parameterized types, unions, intersections, and complements.
+
 =item C<< coerce >> I<< (Bool) >>
 
 MooX::Press automatically implies C<< coerce => 1 >> when you give a
